@@ -13,11 +13,6 @@ NETSUITE settings, checking for user settings first, then falling
 back to the defaults.
 """
 from .module_loading import import_string
-from pathlib import Path
-from dotenv import load_dotenv
-import os
-
-load_dotenv()
 
 django_imported = False
 try:
@@ -34,30 +29,6 @@ try:
 except ImportError as e:
     settings = None
 
-if os.environ.get('BASE_DIR')is not None:
-    BASE_DIR = Path(os.environ.get('BASE_DIR'))
-else:
-    BASE_DIR = Path(__file__).parent.parent.parent.parent.parent.parent.resolve()
-BASE_CONFIG_DIR = Path.joinpath(BASE_DIR, 'config')
-if os.environ.get("NETSUITE_CONFIG_DIR") is not None:
-    NETSUITE_CONFIG_DIR = Path(os.environ.get("NETSUITE_CONFIG_DIR"))
-else:
-    NETSUITE_CONFIG_DIR = Path.joinpath(BASE_CONFIG_DIR, 'netsuite')
-
-if os.environ.get("NETSUITE_TOKENS_DIR") is not None:
-    NETSUITE_TOKENS_DIR = Path(os.environ.get("NETSUITE_TOKENS_DIR"))
-else:
-    NETSUITE_TOKENS_DIR = Path.joinpath(BASE_CONFIG_DIR, 'tokens')
-PACKAGE_DIR = Path(__file__).parent.resolve()
-NETSUITE_CLIENT_DIR = Path.joinpath(BASE_DIR, 'netsuite_rest_client')
-
-if not os.path.exists(NETSUITE_CONFIG_DIR):
-    os.makedirs(NETSUITE_CONFIG_DIR)
-if not os.path.exists(NETSUITE_TOKENS_DIR):
-    os.makedirs(NETSUITE_TOKENS_DIR)
-if not os.path.exists(NETSUITE_CLIENT_DIR):
-    os.makedirs(NETSUITE_CLIENT_DIR)
-
 
 JSON_STORAGE = 'netsuite.storages.JSONStorage'
 IN_MEMORY_STORAGE = 'netsuite.storages.InMemoryStorage'
@@ -71,7 +42,7 @@ DEFAULTS = {
     # API Configuration
     'NETSUITE_APP_NAME': None,
     'CLIENT_ID': None,
-
+    'NETSUITE_KEY_FILE': './netsuite_key.pem',
     'CERT_ID': None,
     # 'CLIENT_SECRET': None,
     # 'REDIRECT_URL': 'https://theapiguys.com',
@@ -79,14 +50,11 @@ DEFAULTS = {
     'ALLOW_NONE': False,
     'USE_DATETIME': True,
 
-
-
     'STORAGE_CLASS': 'netsuite.storages.JSONStorage',
-    'CREDENTIALS_PATH': str(Path.joinpath(NETSUITE_CONFIG_DIR, 'netsuite_credentials.json')),
-    'JSON_STORAGE_PATH': str(Path.joinpath(NETSUITE_TOKENS_DIR, 'netsuite_tokens.json')),
-    'NETSUITE_CERTIFICATE_FILE': str(Path.joinpath(NETSUITE_CONFIG_DIR, 'netsuite_certificate.pem')),
-    'NETSUITE_KEY_FILE': str(Path.joinpath(NETSUITE_CONFIG_DIR, 'netsuite_key.pem')),
-    'NETSUITE_CLIENT_PATH': str(Path.joinpath(BASE_DIR, 'netsuite_rest_client')),
+    'CREDENTIALS_PATH': './netsuite-credentials.json',
+    'JSON_STORAGE_PATH': './netsuite-tokens.json',
+    'NETSUITE_CERTIFICATE_PATH': './netsuite_certificate.pem',
+
     'APP_NAME': 'default',
 }
 
